#
# spec file for package deltarpm
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

# we don't want to provide private python extension libs
%define _exclude_files_from_autoprov %{python3_sitearch}/.*\\.so
%define snap %nil

Name:           deltarpm
Version:        3.6.3
Release:        %mkrel 4
Summary:        Tools to Create and Apply deltarpms
License:        BSD-3-Clause
Group:          System/Packaging
URL:            https://github.com/rpm-software-management/deltarpm
%if 0%{?snap}
# Generate source by doing:
# git clone https://github.com/rpm-software-management/deltarpm.git
# cd deltarpm
# git archive --format=tar --prefix="deltarpm-git-20120324/" 7ed5208 | \
# bzip2 > deltarpm-git-20120324.tar.bz2
Source:		%{name}-%{version}-20120324.tar.bz2
%else
Source:         %{url}/archive/%{version}/%{name}-%{version}.tar.gz
%endif
# Patches from Fedora
# Mageia patches
BuildRequires:  libbzip2-devel
BuildRequires:  libzstd-devel
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(rpm) >= 4.12.90
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  perl-devel
# we need to build against recent rpm, so avoid the new payload
%define _binary_payload w9.bzdio

%description
This package contains tools to create and apply deltarpms. A deltarpm
contains the difference between an old and a new version of an RPM,
which makes it possible to recreate the new RPM from the deltarpm and
the old one. You do not need to have a copy of the old RPM, because
deltarpms can also work with installed RPMs.

%package -n python3-deltarpm
Summary:        Tools to Create and Apply deltarpms
Group:          Development/Python
Requires:       %{name} = %{version}

%description -n python3-deltarpm
Python bindings for deltarpm

%package -n perl-deltarpm
Summary:        Tools to Create and Apply deltarpms
Group:          Development/Perl
Requires:       %{name} = %{version}
Conflicts:      %{name} <= 3.6.1-11

%description -n perl-deltarpm
Perl bindings for deltarpm

%prep
%if 0%{?snap}
%setup -q -n %{name}-git-20120324
%else
%setup -q
%endif
%autopatch -p1

%build
make rpmdumpheader="%{_libdir}/rpm/rpmdumpheader" %{?_smp_mflags} prefix=%{_prefix} mandir=%{_mandir} bindir=%{_bindir}
make rpmdumpheader="%{_libdir}/rpm/rpmdumpheader" %{?_smp_mflags} prefix=%{_prefix} mandir=%{_mandir} bindir=%{_bindir} python
pushd perl
perl Makefile.PL INSTALLDIRS=vendor
make
popd

%install
mkdir -p %{buildroot}%{_libdir}/rpm
make rpmdumpheader="%{_libdir}/rpm/rpmdumpheader" DESTDIR=%{buildroot} prefix=%{_prefix} mandir=%{_mandir} bindir=%{_bindir} install
# Remove wrongly installed Python module
rm -rf %{buildroot}%{_libdir}/python/site-packages/{_deltarpmmodule.so,deltarpm.py}

rm -rf %{buildroot}/usr/local

%make_install -C perl

%files
%doc README LICENSE.BSD
%{_bindir}/[^d]*
%{_mandir}/man8/*
%{_libdir}/rpm/rpmdumpheader

%files -n python3-deltarpm
%{python3_sitearch}/deltarpm.py
%{python3_sitearch}/_deltarpmmodule.so
%{python3_sitearch}/__pycache__/*

%files -n perl-deltarpm
%{_bindir}/drpmsync
%{perl_vendorarch}/auto/deltarpm/deltarpm.so
%{perl_vendorarch}/deltarpm.pm
%{_mandir}/man3/deltarpm.*


%changelog
* Fri Aug 23 2024 tv <tv> 3.6.3-4.mga10
+ Revision: 2089666
- Rebuild for perl-5.40

* Mon Dec 18 2023 papoteur <papoteur> 3.6.3-3.mga10
+ Revision: 2019025
- Mass Rebuild - Python 3.12

* Sun Nov 12 2023 daviddavid <daviddavid> 3.6.3-2.mga10
+ Revision: 2006246
- rebuild for new rpm 4.19.0

* Mon Aug 01 2022 bcornec <bcornec> 3.6.3-1.mga9
+ Revision: 1874072
- Update to upstream deltarpm 3.6.3

* Mon Jun 06 2022 umeabot <umeabot> 3.6.2-8.mga9
+ Revision: 1861487
- Rebuild for Perl 5.36

* Mon Mar 28 2022 umeabot <umeabot> 3.6.2-7.mga9
+ Revision: 1829723
- Mageia 9 Mass Rebuild

* Tue Feb 22 2022 tv <tv> 3.6.2-6.mga9
+ Revision: 1782744
- Rebuild for python-3.10

* Mon May 24 2021 umeabot <umeabot> 3.6.2-5.mga9
+ Revision: 1726358
- Rebuild for perl 5.34

* Sat Mar 27 2021 tv <tv> 3.6.2-4.mga9
+ Revision: 1710977
- Rebuild for python 3.9

* Wed Jun 17 2020 umeabot <umeabot> 3.6.2-3.mga8
+ Revision: 1594207
- Rebuild for perl 5.32

* Sun Feb 16 2020 umeabot <umeabot> 3.6.2-2.mga8
+ Revision: 1531283
- Mageia 8 Mass Rebuild

* Tue Sep 10 2019 tv <tv> 3.6.2-1.mga8
+ Revision: 1439336
- new release
- drop python2

* Tue Aug 27 2019 tmb <tmb> 3.6.1-13.mga8
+ Revision: 1433511
- rebuild for perl 5.30

* Tue Jan 08 2019 shlomif <shlomif> 3.6.1-12.mga7
+ Revision: 1352449
- Rebuild for python3 3.7

* Wed Nov 28 2018 tv <tv> 3.6.1-11.mga7
+ Revision: 1336308
- move drpmsync into perl-deltarpm so taht dnf stop pulling full perl in
  minimal install (mga#23894)

* Sun Sep 23 2018 umeabot <umeabot> 3.6.1-10.mga7
+ Revision: 1297422
- Mageia 7 Mass Rebuild

* Tue Aug 07 2018 wally <wally> 3.6.1-9.mga7
+ Revision: 1248828
- add pycache back

* Fri Jul 06 2018 daviddavid <daviddavid> 3.6.1-8.mga7
+ Revision: 1242167
- update files list (no more __pycache__ reference)

* Tue May 08 2018 tv <tv> 3.6.1-7.mga7
+ Revision: 1227726
- rename python-deltarpm as python2-deltarpm

* Thu Aug 31 2017 pterjan <pterjan> 3.6.1-6.mga7
+ Revision: 1150251
- Rebuild for perl ABI changes

* Wed Aug 23 2017 tv <tv> 3.6.1-5.mga7
+ Revision: 1143567
- rebuild for rpm-4.14

* Sat Aug 05 2017 pterjan <pterjan> 3.6.1-4.mga7
+ Revision: 1135200
- Rebuild for python 3.6

* Sat Jul 22 2017 neoclust <neoclust> 3.6.1-3.mga7
+ Revision: 1126949
- Rebuild against new Perl 5.26

* Sat Jun 18 2016 pterjan <pterjan> 3.6.1-2.mga6
+ Revision: 1022113
- Rebuild for perl 5.22.2

* Sun Jan 03 2016 luigiwalser <luigiwalser> 3.6.1-1.mga6
+ Revision: 918718
- 3.6.1 (sync with opensuse)
- update URL
- remove upstreamed patches

* Mon Oct 12 2015 tv <tv> 3.6-17.mga6
+ Revision: 889850
- sync patches with FC (mga#16945)

* Thu Oct 08 2015 daviddavid <daviddavid> 3.6-16.mga6
+ Revision: 887288
- rebuild for python 3.5

* Sun Sep 06 2015 tv <tv> 3.6-15.mga6
+ Revision: 873250
- submit to core/release

* Sun Aug 23 2015 tv <tv> 3.6-14.mga6
+ Revision: 868804
- versionate rpm BR

* Sat Aug 01 2015 tv <tv> 3.6-13.mga6
+ Revision: 860288
- rebuild for rpm-4.13

* Thu Jun 25 2015 sander85 <sander85> 3.6-12.mga6
+ Revision: 843830
- Rebuild for perl 5.22

* Tue Jun 23 2015 tv <tv> 3.6-11.mga6
+ Revision: 841022
- rebuild for perl-5.22

* Wed Oct 15 2014 umeabot <umeabot> 3.6-10.mga5
+ Revision: 738834
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.6-9.mga5
+ Revision: 726078
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.6-8.mga5
+ Revision: 678709
- Mageia 5 Mass Rebuild

* Mon Sep 15 2014 tv <tv> 3.6-7.mga5
+ Revision: 675539
- rebuild for new rpm

* Tue Jun 03 2014 pterjan <pterjan> 3.6-6.mga5
+ Revision: 630768
- Rebuild for perl 5.20

* Sat May 31 2014 pterjan <pterjan> 3.6-5.mga5
+ Revision: 629670
- Rebuild for new Python

* Sat May 31 2014 pterjan <pterjan> 3.6-4.mga5
+ Revision: 628154
- Rebuild for new Python

* Mon Oct 21 2013 umeabot <umeabot> 3.6-3.mga4
+ Revision: 540979
- Mageia 4 Mass Rebuild

* Thu Oct 10 2013 philippem <philippem> 3.6-2.mga4
+ Revision: 494702
- add bytecompiled .py files
- do not provide private python extension libs

* Thu Jun 20 2013 tv <tv> 3.6-1.mga4
+ Revision: 445254
- BR python3-devel
- BR python3
- new release
- new python3 submodule

* Wed May 29 2013 tv <tv> 3.5git-7.mga4
+ Revision: 430008
- rebuild for new perl

* Tue Jan 22 2013 fwang <fwang> 3.5git-6.mga3
+ Revision: 390747
- update rpm group

* Fri Jan 11 2013 umeabot <umeabot> 3.5git-5.mga3
+ Revision: 348720
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Dec 18 2012 tv <tv> 3.5git-4.mga3
+ Revision: 332285
- rebuild for new rpm

* Fri Nov 30 2012 tv <tv> 3.5git-3.mga3
+ Revision: 323493
- BR perl-devel
- patch 1: add a perl binding

* Sun Jun 10 2012 tv <tv> 3.5git-2.mga3
+ Revision: 259361
- rebuild for new rpm-4.10.0

* Sat Mar 24 2012 bcornec <bcornec> 3.5git-1.mga2
+ Revision: 226129
- Update Groups to correct values
- Import deltarpm
- rename previsou pkg
- Created package structure for python-deltarpm.

